"""Autogenerated file: DO NOT EDIT!"""
import typing  # noqa: F401
from dazzler.system import Component, Aspect, UNDEFINED  # noqa: F401


class Dropdown(Component):
    """
    
    """
    _aspect_keys = []
    _children = []
    options = Aspect(required=True, children=True)
    placeholder = Aspect()
    searchable = Aspect()
    multi = Aspect()

    def __init__(
            self,
            options: typing.List[typing.Dict[str, typing.Union[typing.Union[typing.Union[float, int], str], typing.Union[str, int, float, Component, typing.List[typing.Union[str, int, float, Component]]]]]],  # noqa: E501
            placeholder: typing.Optional[str] = UNDEFINED,
            searchable: typing.Optional[bool] = UNDEFINED,
            multi: typing.Optional[bool] = UNDEFINED,
            identity: str = None
    ):
        """
        :param options:
        :param placeholder: Text to show when no value is selected.
        :param searchable:
        :param multi:
        """
        Component.__init__(self, locals(), identity)
